==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/PortworxVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PortworxVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.PortworxVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PortworxVolumeSource,io.fabric8.kubernetes.api.model.PortworxVolumeSourceBuilder>{
  public PortworxVolumeSourceBuilder() {
    this(false);
  }
  public PortworxVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new PortworxVolumeSource(), validationEnabled);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PortworxVolumeSource(), validationEnabled);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.PortworxVolumeSource instance) {
    this(fluent, instance, false);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.PortworxVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFsType(instance.getFsType()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withVolumeID(instance.getVolumeID()); 
    this.validationEnabled = validationEnabled; 
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSource instance) {
    this(instance,false);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFsType(instance.getFsType()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withVolumeID(instance.getVolumeID()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PortworxVolumeSource build() {
    PortworxVolumeSource buildable = new PortworxVolumeSource(fluent.getFsType(),fluent.getReadOnly(),fluent.getVolumeID());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortworxVolumeSourceBuilder that = (PortworxVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PortworxVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PortworxVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.PortworxVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PortworxVolumeSource,io.fabric8.kubernetes.api.model.PortworxVolumeSourceBuilder>{
  public PortworxVolumeSourceBuilder() {
    this(false);
  }
  public PortworxVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new PortworxVolumeSource(), validationEnabled);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PortworxVolumeSource(), validationEnabled);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.PortworxVolumeSource instance) {
    this(fluent, instance, false);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.PortworxVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFsType(instance.getFsType()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withVolumeID(instance.getVolumeID()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSource instance) {
    this(instance,false);
  }
  public PortworxVolumeSourceBuilder(io.fabric8.kubernetes.api.model.PortworxVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFsType(instance.getFsType()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withVolumeID(instance.getVolumeID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PortworxVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PortworxVolumeSource build() {
    PortworxVolumeSource buildable = new PortworxVolumeSource(fluent.getFsType(),fluent.getReadOnly(),fluent.getVolumeID());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortworxVolumeSourceBuilder that = (PortworxVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
